@@ -22,6 +22,7 @@ from pyplumio.devices import Addressable, Mixer, Thermostat
 from pyplumio.frames import DataFrameDescription, get_frame_handler, is_known_frame_type
 from pyplumio.helpers.factory import factory
 from pyplumio.helpers.filters import on_change
+from pyplumio.helpers.network_info import NetworkInfo
 from pyplumio.helpers.product_info import ProductType
 from pyplumio.helpers.schedule import Schedule, ScheduleDay
 from pyplumio.helpers.typing import DeviceDataType, ParameterDataType, VersionsInfoType
@@ -99,9 +100,9 @@ class EcoMAX(Addressable):
     _frame_versions: VersionsInfoType
     _fuel_burned_timestamp: float = 0.0
 
-    def __init__(self, queue: asyncio.Queue):
+    def __init__(self, queue: asyncio.Queue, network: NetworkInfo):
         """Initialize new ecoMAX object."""
-        super().__init__(queue)
+        super().__init__(queue, network)
         self._frame_versions = {}
         self._fuel_burned_timestamp = time.time()
         self.subscribe(ATTR_SENSORS, self._add_ecomax_sensors)
