@@ -89,12 +89,12 @@ class ThermostatParameterDescription(ParameterDescription):
 THERMOSTAT_PARAMETERS: Tuple[ThermostatParameterDescription, ...] = (
     ThermostatParameterDescription(name="mode"),
     ThermostatParameterDescription(name="party_target_temp", size=2, multiplier=10),
-    ThermostatParameterDescription(name="summer_target_temp", size=2, multiplier=10),
+    ThermostatParameterDescription(name="holidays_target_temp", size=2, multiplier=10),
     ThermostatParameterDescription(name="correction"),
     ThermostatParameterDescription(name="away_timer"),
-    ThermostatParameterDescription(name="vent_timer"),
+    ThermostatParameterDescription(name="airing_timer"),
     ThermostatParameterDescription(name="party_timer"),
-    ThermostatParameterDescription(name="holiday_timer"),
+    ThermostatParameterDescription(name="holidays_timer"),
     ThermostatParameterDescription(name="hysteresis", multiplier=10),
     ThermostatParameterDescription(name="day_target_temp", size=2, multiplier=10),
     ThermostatParameterDescription(name="night_target_temp", size=2, multiplier=10),
